import { Component, h, State, Prop, Watch, Event } from '@stencil/core';
import { generateId } from '@boldpenguin/sdk-utility';
export class BpSdkQuestionSetButton {
  constructor() {
    /**
     * Text to be displayed
     */
    this.text = '';
    /**
     * Id for button
     */
    this.buttonId = generateId(8);
    /**
     * Controls disabled state of button
     */
    this.buttonDisabled = false;
    this.useExternal = false;
    this.cssClasses = 'bp-sdk-question-set-button__container';
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-set-button');
    customElements.whenDefined('bp-sdk-external-question-set-button').then(() => {
      this.useExternal = true;
    });
    this.calculateButtonClasses(this.extraCssClasses);
  }
  calculateButtonClasses(extraClasses = '') {
    this.cssClasses = `bp-sdk-question-set-button__container ${extraClasses}`;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-question-set-button", { buttonDisabled: this.buttonDisabled, buttonId: this.buttonId, text: this.text });
  }
  renderInternal() {
    return h("bp-sdk-button", { buttonDisabled: this.buttonDisabled, buttonId: this.buttonId, class: this.cssClasses, text: this.text });
  }
  static get is() { return "bp-sdk-question-set-button"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-question-set-button.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-question-set-button.css"]
  }; }
  static get properties() { return {
    "text": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Text to be displayed"
      },
      "attribute": "text",
      "reflect": false,
      "defaultValue": "''"
    },
    "buttonId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Id for button"
      },
      "attribute": "button-id",
      "reflect": false,
      "defaultValue": "generateId(8)"
    },
    "buttonDisabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Controls disabled state of button"
      },
      "attribute": "button-disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "extraCssClasses": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Extra CSS classes to be added onto the question set button"
      },
      "attribute": "extra-css-classes",
      "reflect": false
    }
  }; }
  static get states() { return {
    "useExternal": {},
    "cssClasses": {}
  }; }
  static get events() { return [{
      "method": "saveQuestionSet",
      "name": "saveQuestionSet",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "extraCssClasses",
      "methodName": "calculateButtonClasses"
    }]; }
}
